@@ -696,7 +696,7 @@ tinyplot.default = function(
 
   # catch for adding to existing facet plot
   if (!is.null(facet) && add) {
-    if (Sys.getenv("POSITRON") == 1) warning(
+    if (Sys.getenv("POSITRON") == 1 && interactive()) warning(
       "Positron IDE detected.\n",
       "Adding layers to a faceted tinyplot in Positron leads to known alignment errors. Please see:\n",
       "https://github.com/posit-dev/positron/issues/7316"
