@@ -28,6 +28,13 @@ more_than_n_unique = function(x, n, small_vec_len = 1e3L) {
   }
 }
 
+
+## Null coalescing operator
+if (getRversion() <= "4.4.0") {
+   `%||%` = function(x, y) if (is.null(x)) y else x
+}
+
+
 ## Function that computes an appropriate bandwidth kernel based on a string
 ## input
 bw_fun = function(kernel, x) {
@@ -41,4 +48,4 @@ bw_fun = function(kernel, x) {
         sj   = bw.SJ(x),
         stop("Invalid `bw` string. Choose from 'nrd0', 'nrd', 'ucv', 'bcv', or 'SJ'.")
     )
-}
\ No newline at end of file
+}
